"""Account Report v1 package."""

# ===================================================================
# AUTO-GENERATED SECTION - ONLY EDIT BELOW THE CLOSING COMMENT BLOCK
# ===================================================================
# This section is automatically managed by protoc-gen-meshpy.
#
# DO NOT EDIT ANYTHING IN THIS SECTION MANUALLY!
# Your changes will be overwritten during code generation.
#
# To add custom imports and exports, scroll down to the
# "MANUAL SECTION" indicated below.
# ===================================================================

# Generated protobuf imports
from .fee_entry_pb2 import FeeEntry
from .income_entry_pb2 import IncomeEntry, IncomeNarrative
from .trading_statement_entry_pb2 import TradingStatementEntry
from .disclaimer_pb2 import Disclaimer
from .account_report_pb2 import AccountReport
from .service_pb2 import GetAccountReportRequest, GetExcelAccountReportRequest, GetExcelAccountReportResponse

# Generated service imports
from .service_meshpy import (
    AccountReportService,
    AccountReportServiceGRPCClient,
    AccountReportServiceGRPCClientInterface,
)

# ===================================================================
# END OF AUTO-GENERATED SECTION
# ===================================================================
#
# MANUAL SECTION - ADD YOUR CUSTOM IMPORTS AND EXPORTS BELOW
#
# You can safely add your own imports, functions, classes, and exports
# in this section. They will be preserved across code generation.
#
# Example:
#   from my_custom_module import my_function
#
# ===================================================================

from .income_entry import income_narrative_pretty_string

# ===================================================================
# MODULE EXPORTS
# ===================================================================
# Combined auto-generated and manual exports
__all__ = [
    # Generated exports
    "AccountReport",
    "AccountReportService",
    "AccountReportServiceGRPCClient",
    "AccountReportServiceGRPCClientInterface",
    "Disclaimer",
    "FeeEntry",
    "GetAccountReportRequest",
    "GetExcelAccountReportRequest",
    "GetExcelAccountReportResponse",
    "IncomeEntry",
    "IncomeNarrative",
    "TradingStatementEntry",
    # Manual exports
    "income_narrative_pretty_string",
]



"""Role v1 package."""

# ===================================================================
# AUTO-GENERATED SECTION - ONLY EDIT BELOW THE CLOSING COMMENT BLOCK
# ===================================================================
# This section is automatically managed by protoc-gen-meshpy.
#
# DO NOT EDIT ANYTHING IN THIS SECTION MANUALLY!
# Your changes will be overwritten during code generation.
#
# To add custom imports and exports, scroll down to the
# "MANUAL SECTION" indicated below.
# ===================================================================

# Generated protobuf imports
from .role_pb2 import Role

# ===================================================================
# END OF AUTO-GENERATED SECTION
# ===================================================================
#
# MANUAL SECTION - ADD YOUR CUSTOM IMPORTS AND EXPORTS BELOW
#
# You can safely add your own imports, functions, classes, and exports
# in this section. They will be preserved across code generation.
#
# Example:
#   from my_custom_module import my_function
#
# ===================================================================

from .role import (
    must_parse_role_parts,
    parse_role_parts,
    role_from_full_resource_name,
    role_full_resource_name_from_group,
    role_full_resource_name_from_group_id,
    role_is_valid,
    role_is_valid_and_specified,
)

# ===================================================================
# MODULE EXPORTS
# ===================================================================
# Combined auto-generated and manual exports
__all__ = [
    # Generated exports
    "Role",
    # Manual exports
    "must_parse_role_parts",
    "parse_role_parts",
    "role_from_full_resource_name",
    "role_full_resource_name_from_group",
    "role_full_resource_name_from_group_id",
    "role_is_valid",
    "role_is_valid_and_specified",
]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/trading/limit_order/v1/limit_order.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/trading/limit_order/v1/limit_order.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from meshtrade.type.v1 import amount_pb2 as meshtrade_dot_type_dot_v1_dot_amount__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2meshtrade/trading/limit_order/v1/limit_order.proto\x12 meshtrade.trading.limit_order.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1emeshtrade/type/v1/amount.proto\"\x9d\x08\n\nLimitOrder\x12\xc8\x01\n\x04name\x18\x01 \x01(\tB\xb3\x01\xbaH\xaf\x01\xba\x01\xab\x01\n\x14name.format.optional\x12\x39name must be empty or in the format limit_orders/{ULIDv2}\x1aXsize(this) == 0 || this.matches(\'^limit_orders/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')R\x04name\x12R\n\x05owner\x18\x02 \x01(\tB<\xbaH9r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01!\xc8\x01\x01R\x05owner\x12V\n\x06owners\x18\x03 \x03(\tB>\xbaH;\x92\x01\x38\"6r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01!R\x06owners\x12X\n\x07\x61\x63\x63ount\x18\x05 \x01(\tB>\xbaH;r621^accounts/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01#\xc8\x01\x01R\x07\x61\x63\x63ount\x12\x37\n\x12\x65xternal_reference\x18\x06 \x01(\tB\x08\xbaH\x05r\x03\x18\xc8\x01R\x11\x65xternalReference\x12P\n\x04side\x18\x07 \x01(\x0e\x32\x30.meshtrade.trading.limit_order.v1.LimitOrderSideB\n\xbaH\x07\x82\x01\x04\x10\x01 \x00R\x04side\x12\x42\n\x0blimit_price\x18\x08 \x01(\x0b\x32\x19.meshtrade.type.v1.AmountB\x06\xbaH\x03\xc8\x01\x01R\nlimitPrice\x12=\n\x08quantity\x18\t \x01(\x0b\x32\x19.meshtrade.type.v1.AmountB\x06\xbaH\x03\xc8\x01\x01R\x08quantity\x12\x38\n\nfill_price\x18\n \x01(\x0b\x32\x19.meshtrade.type.v1.AmountR\tfillPrice\x12\x42\n\x0f\x66illed_quantity\x18\x0b \x01(\x0b\x32\x19.meshtrade.type.v1.AmountR\x0e\x66illedQuantity\x12G\n\x05state\x18\x0c \x01(\x0e\x32\x31.meshtrade.trading.limit_order.v1.LimitOrderStateR\x05state\x12\x16\n\x06number\x18\r \x01(\tR\x06number\x12=\n\x0csubmitted_at\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0bsubmittedAtJ\x04\x08\x04\x10\x05R\x0c\x64isplay_name*g\n\x0eLimitOrderSide\x12 \n\x1cLIMIT_ORDER_SIDE_UNSPECIFIED\x10\x00\x12\x18\n\x14LIMIT_ORDER_SIDE_BUY\x10\x01\x12\x19\n\x15LIMIT_ORDER_SIDE_SELL\x10\x02*\xc4\x02\n\x0fLimitOrderState\x12!\n\x1dLIMIT_ORDER_STATE_UNSPECIFIED\x10\x00\x12,\n(LIMIT_ORDER_STATE_SUBMISSION_IN_PROGRESS\x10\x01\x12\'\n#LIMIT_ORDER_STATE_SUBMISSION_FAILED\x10\x02\x12\x1a\n\x16LIMIT_ORDER_STATE_OPEN\x10\x03\x12*\n&LIMIT_ORDER_STATE_COMPLETE_IN_PROGRESS\x10\x04\x12\x1e\n\x1aLIMIT_ORDER_STATE_COMPLETE\x10\x05\x12.\n*LIMIT_ORDER_STATE_CANCELLATION_IN_PROGRESS\x10\x06\x12\x1f\n\x1bLIMIT_ORDER_STATE_CANCELLED\x10\x07\x42l\n\'co.meshtrade.api.trading.limit_order.v1ZAgithub.com/meshtrade/api/go/trading/limit_order/v1;limit_order_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.trading.limit_order.v1.limit_order_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'co.meshtrade.api.trading.limit_order.v1ZAgithub.com/meshtrade/api/go/trading/limit_order/v1;limit_order_v1'
  _globals['_LIMITORDER'].fields_by_name['name']._loaded_options = None
  _globals['_LIMITORDER'].fields_by_name['name']._serialized_options = b'\272H\257\001\272\001\253\001\n\024name.format.optional\0229name must be empty or in the format limit_orders/{ULIDv2}\032Xsize(this) == 0 || this.matches(\'^limit_orders/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')'
  _globals['_LIMITORDER'].fields_by_name['owner']._loaded_options = None
  _globals['_LIMITORDER'].fields_by_name['owner']._serialized_options = b'\272H9r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001!\310\001\001'
  _globals['_LIMITORDER'].fields_by_name['owners']._loaded_options = None
  _globals['_LIMITORDER'].fields_by_name['owners']._serialized_options = b'\272H;\222\0018\"6r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001!'
  _globals['_LIMITORDER'].fields_by_name['account']._loaded_options = None
  _globals['_LIMITORDER'].fields_by_name['account']._serialized_options = b'\272H;r621^accounts/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001#\310\001\001'
  _globals['_LIMITORDER'].fields_by_name['external_reference']._loaded_options = None
  _globals['_LIMITORDER'].fields_by_name['external_reference']._serialized_options = b'\272H\005r\003\030\310\001'
  _globals['_LIMITORDER'].fields_by_name['side']._loaded_options = None
  _globals['_LIMITORDER'].fields_by_name['side']._serialized_options = b'\272H\007\202\001\004\020\001 \000'
  _globals['_LIMITORDER'].fields_by_name['limit_price']._loaded_options = None
  _globals['_LIMITORDER'].fields_by_name['limit_price']._serialized_options = b'\272H\003\310\001\001'
  _globals['_LIMITORDER'].fields_by_name['quantity']._loaded_options = None
  _globals['_LIMITORDER'].fields_by_name['quantity']._serialized_options = b'\272H\003\310\001\001'
  _globals['_LIMITORDERSIDE']._serialized_start=1238
  _globals['_LIMITORDERSIDE']._serialized_end=1341
  _globals['_LIMITORDERSTATE']._serialized_start=1344
  _globals['_LIMITORDERSTATE']._serialized_end=1668
  _globals['_LIMITORDER']._serialized_start=183
  _globals['_LIMITORDER']._serialized_end=1236
# @@protoc_insertion_point(module_scope)



# Code generated by protoc-gen-meshpy. DO NOT EDIT.
# source: meshtrade/iam/api_user/v1/service.proto

"""
APIUserService gRPC service wrapper with authentication, timeouts, and resource management.

This module provides a high-level gRPC service for the APIUserService service that combines
the service interface with resource management capabilities, providing authentication,
timeouts, and proper connection handling.
"""

from collections.abc import Iterator
from datetime import timedelta
from typing import Optional

from meshtrade.common import BaseGRPCClient
from .api_credentials import find_credentials

from .api_user_pb2 import APIUser
from meshtrade.common.service_options import ServiceOptions
from .service_pb2 import (
ActivateAPIUserRequest,
AssignRolesToAPIUserRequest,
CreateAPIUserRequest,
DeactivateAPIUserRequest,
GetAPIUserByKeyHashRequest,
GetAPIUserRequest,
ListAPIUsersRequest,
ListAPIUsersResponse,
RevokeRolesFromAPIUserRequest,
SearchAPIUsersRequest,
SearchAPIUsersResponse,
)
from .service_pb2_grpc import APIUserServiceStub


def _create_apiuserservice_stub(channel):
    """Factory function to create APIUserServiceStub from gRPC channel."""
    return APIUserServiceStub(channel)


class APIUserService(BaseGRPCClient):
    """APIUserService gRPC service with authentication, timeouts, and resource management.

    This service provides a complete implementation of the APIUserService with proper authentication, timeout handling, and automatic resource cleanup.

    Full Service documentation: https://meshtrade.github.io/api/docs/api-reference/iam/api_user/v1

    Basic service usage with default SDK Configuration:
    ```python
    service = APIUserService()

    with service:   # `with` ensures proper clean up of underlying connection after use
        response = service.get_api_user(request)
    ```
        
    With default configuration API credentials are searched for using the standard discovery hierarchy:
    
    1. MESH_API_CREDENTIALS environment variable
    
    2. Default credential file location:
    
    - Linux:   `$XDG_CONFIG_HOME/mesh/credentials.json` or fallback to `$HOME/.config/mesh/credentials.json`
    - macOS:   `$HOME/Library/Application Support/mesh/credentials.json`
    - Windows: `C:\\Users\\<user>\\AppData\\Roaming\\mesh\\credentials.json`
    
    For more information on authentication: https://meshtrade.github.io/api/docs/architecture/authentication

    The service may also be configured with custom options:
    ```python
    from .service_options_meshpy import ServiceOptions
    from datetime import timedelta

    options = ServiceOptions(
        url="api.staging.example.com",
        port=443,
        api_key="your-api-key",
        group="groups/your-group-id",
        timeout=timedelta(seconds=60)
    )

    service = APIUserService(options)

    with service: # `with` ensures proper clean up of underlying connection after use
        response = service.get_api_user(request)
    ```

    For more information on service configuration: https://meshtrade.github.io/api/docs/architecture/sdk-configuration
    """

    def __init__(self, options: Optional[ServiceOptions] = None):
        """Construct and initialize the APIUserService service.

        Full Service documentation: https://meshtrade.github.io/api/docs/api-reference/iam/api_user/v1

        Args:
            options: Optional ServiceOptions for configuring the service.
                    If None, service is constructed with default configuration.
                    With default configuration API credentials are searched for using the standard discovery hierarchy:
                    
                    1. MESH_API_CREDENTIALS environment variable
                    
                    2. Default credential file location:
                    
                    - Linux:   `$XDG_CONFIG_HOME/mesh/credentials.json` or fallback to `$HOME/.config/mesh/credentials.json`
                    - macOS:   `$HOME/Library/Application Support/mesh/credentials.json`
                    - Windows: `C:\\Users\\<user>\\AppData\\Roaming\\mesh\\credentials.json`      

                    For more information on authentication: https://meshtrade.github.io/api/docs/architecture/authentication

                    For more information on service configuration: https://meshtrade.github.io/api/docs/architecture/sdk-configuration            

        Example:
        ```python
        # construct with default configuration
        service = APIUserService()

        # construct with custom configuration
        options = ServiceOptions(
            url="api.example.com",
            api_key="your-key",
            group="groups/your-group"
        )
        service = APIUserService(options)
        ```
        """
        if options is None:
            options = ServiceOptions()

        # Initialize the base client with all common functionality
        super().__init__(
            service_name="APIUserService",
            stub_factory=_create_apiuserservice_stub,
            find_credentials_func=find_credentials,
            url=options.url,
            port=options.port,
            api_key=options.api_key,
            group=options.group,
            timeout=options.timeout,
            tls=options.tls,
        )

    def get_apiuser(self, request: GetAPIUserRequest, timeout: Optional[timedelta] = None) -> APIUser:
        """GetAPIUser method.

        Args:
            request: The GetAPIUser request message
            timeout: Optional timeout override for this call

        Returns:
            The GetAPIUser response message

        Raises:
            grpc.RpcError: If the gRPC call fails
            ValueError: If authentication credentials are missing
        """
        return self._execute_method("GetAPIUser", request, timeout)

    def create_apiuser(self, request: CreateAPIUserRequest, timeout: Optional[timedelta] = None) -> APIUser:
        """CreateAPIUser method.

        Args:
            request: The CreateAPIUser request message
            timeout: Optional timeout override for this call

        Returns:
            The CreateAPIUser response message

        Raises:
            grpc.RpcError: If the gRPC call fails
            ValueError: If authentication credentials are missing
        """
        return self._execute_method("CreateAPIUser", request, timeout)

    def assign_roles_to_apiuser(self, request: AssignRolesToAPIUserRequest, timeout: Optional[timedelta] = None) -> APIUser:
        """AssignRolesToAPIUser method.

        Args:
            request: The AssignRolesToAPIUser request message
            timeout: Optional timeout override for this call

        Returns:
            The AssignRolesToAPIUser response message

        Raises:
            grpc.RpcError: If the gRPC call fails
            ValueError: If authentication credentials are missing
        """
        return self._execute_method("AssignRolesToAPIUser", request, timeout)

    def revoke_roles_from_apiuser(self, request: RevokeRolesFromAPIUserRequest, timeout: Optional[timedelta] = None) -> APIUser:
        """RevokeRolesFromAPIUser method.

        Args:
            request: The RevokeRolesFromAPIUser request message
            timeout: Optional timeout override for this call

        Returns:
            The RevokeRolesFromAPIUser response message

        Raises:
            grpc.RpcError: If the gRPC call fails
            ValueError: If authentication credentials are missing
        """
        return self._execute_method("RevokeRolesFromAPIUser", request, timeout)

    def list_apiusers(self, request: ListAPIUsersRequest, timeout: Optional[timedelta] = None) -> ListAPIUsersResponse:
        """ListAPIUsers method.

        Args:
            request: The ListAPIUsers request message
            timeout: Optional timeout override for this call

        Returns:
            The ListAPIUsers response message

        Raises:
            grpc.RpcError: If the gRPC call fails
            ValueError: If authentication credentials are missing
        """
        return self._execute_method("ListAPIUsers", request, timeout)

    def search_apiusers(self, request: SearchAPIUsersRequest, timeout: Optional[timedelta] = None) -> SearchAPIUsersResponse:
        """SearchAPIUsers method.

        Args:
            request: The SearchAPIUsers request message
            timeout: Optional timeout override for this call

        Returns:
            The SearchAPIUsers response message

        Raises:
            grpc.RpcError: If the gRPC call fails
            ValueError: If authentication credentials are missing
        """
        return self._execute_method("SearchAPIUsers", request, timeout)

    def activate_apiuser(self, request: ActivateAPIUserRequest, timeout: Optional[timedelta] = None) -> APIUser:
        """ActivateAPIUser method.

        Args:
            request: The ActivateAPIUser request message
            timeout: Optional timeout override for this call

        Returns:
            The ActivateAPIUser response message

        Raises:
            grpc.RpcError: If the gRPC call fails
            ValueError: If authentication credentials are missing
        """
        return self._execute_method("ActivateAPIUser", request, timeout)

    def deactivate_apiuser(self, request: DeactivateAPIUserRequest, timeout: Optional[timedelta] = None) -> APIUser:
        """DeactivateAPIUser method.

        Args:
            request: The DeactivateAPIUser request message
            timeout: Optional timeout override for this call

        Returns:
            The DeactivateAPIUser response message

        Raises:
            grpc.RpcError: If the gRPC call fails
            ValueError: If authentication credentials are missing
        """
        return self._execute_method("DeactivateAPIUser", request, timeout)

    def get_apiuser_by_key_hash(self, request: GetAPIUserByKeyHashRequest, timeout: Optional[timedelta] = None) -> APIUser:
        """GetAPIUserByKeyHash method.

        Args:
            request: The GetAPIUserByKeyHash request message
            timeout: Optional timeout override for this call

        Returns:
            The GetAPIUserByKeyHash response message

        Raises:
            grpc.RpcError: If the gRPC call fails
            ValueError: If authentication credentials are missing
        """
        return self._execute_method("GetAPIUserByKeyHash", request, timeout)


# Create aliases to match expected exports
APIUserServiceGRPCClient = APIUserService
APIUserServiceGRPCClientInterface = APIUserService



"""Token Tap v1 package."""

# ===================================================================
# AUTO-GENERATED SECTION - ONLY EDIT BELOW THE CLOSING COMMENT BLOCK
# ===================================================================
# This section is automatically managed by protoc-gen-meshpy.
#
# DO NOT EDIT ANYTHING IN THIS SECTION MANUALLY!
# Your changes will be overwritten during code generation.
#
# To add custom imports and exports, scroll down to the
# "MANUAL SECTION" indicated below.
# ===================================================================

# Generated protobuf imports
from .option_pb2 import (
    MintTokenOptions,
    StellarMintOption,
    StellarMintOptions,
    StellarMintTokenWithMemo,
)
from .service_pb2 import (
    InitialiseTokenTapsRequest,
    InitialiseTokenTapsResponse,
    ListTokenTapsRequest,
    ListTokenTapsResponse,
    MintTokenRequest,
    MintTokenResponse,
)

# Generated service imports
from .service_meshpy import (
    TokenTapService,
    TokenTapServiceGRPCClient,
    TokenTapServiceGRPCClientInterface,
)

# ===================================================================
# END OF AUTO-GENERATED SECTION
# ===================================================================
#
# MANUAL SECTION - ADD YOUR CUSTOM IMPORTS AND EXPORTS BELOW
#
# You can safely add your own imports, functions, classes, and exports
# in this section. They will be preserved across code generation.
#
# Example:
#   from my_custom_module import my_function
#
# ===================================================================

# ===================================================================
# MODULE EXPORTS
# ===================================================================
# Combined auto-generated and manual exports
__all__ = [
    # Generated exports
    "InitialiseTokenTapsRequest",
    "InitialiseTokenTapsResponse",
    "ListTokenTapsRequest",
    "ListTokenTapsResponse",
    "MintTokenOptions",
    "MintTokenRequest",
    "MintTokenResponse",
    "StellarMintOption",
    "StellarMintOptions",
    "StellarMintTokenWithMemo",
    "TokenTapService",
    "TokenTapServiceGRPCClient",
    "TokenTapServiceGRPCClientInterface",
]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/compliance/client/v1/tax_residency.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/compliance/client/v1/tax_residency.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2meshtrade/compliance/client/v1/tax_residency.proto\x12\x1emeshtrade.compliance.client.v1\x1a\x1b\x62uf/validate/validate.proto\"\xec\x01\n\x0cTaxResidency\x12\xc0\x01\n\x0c\x63ountry_code\x18\x01 \x01(\tB\x9c\x01\xbaH\x98\x01\xba\x01\x94\x01\n\x1c\x63ountry_code.format.optional\x12\x45\x63ountry_code must be empty or a valid ISO 3166-1 alpha-2 country code\x1a-size(this) == 0 || this.matches(\'^[A-Z]{2}$\')R\x0b\x63ountryCode\x12\x19\n\x03tin\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x18\x64R\x03tinBc\n%co.meshtrade.api.compliance.client.v1Z:github.com/meshtrade/api/go/compliance/client/v1;client_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.compliance.client.v1.tax_residency_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%co.meshtrade.api.compliance.client.v1Z:github.com/meshtrade/api/go/compliance/client/v1;client_v1'
  _globals['_TAXRESIDENCY'].fields_by_name['country_code']._loaded_options = None
  _globals['_TAXRESIDENCY'].fields_by_name['country_code']._serialized_options = b'\272H\230\001\272\001\224\001\n\034country_code.format.optional\022Ecountry_code must be empty or a valid ISO 3166-1 alpha-2 country code\032-size(this) == 0 || this.matches(\'^[A-Z]{2}$\')'
  _globals['_TAXRESIDENCY'].fields_by_name['tin']._loaded_options = None
  _globals['_TAXRESIDENCY'].fields_by_name['tin']._serialized_options = b'\272H\004r\002\030d'
  _globals['_TAXRESIDENCY']._serialized_start=116
  _globals['_TAXRESIDENCY']._serialized_end=352
# @@protoc_insertion_point(module_scope)



from buf.validate import validate_pb2 as _validate_pb2
from meshtrade.market_data.price.v1 import price_pb2 as _price_pb2
from meshtrade.option.method_options.v1 import method_options_pb2 as _method_options_pb2
from meshtrade.type.v1 import token_pb2 as _token_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetCurrentPriceByTokenPairRequest(_message.Message):
    __slots__ = ("base_token", "quote_token")
    BASE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    QUOTE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    base_token: _token_pb2.Token
    quote_token: _token_pb2.Token
    def __init__(self, base_token: _Optional[_Union[_token_pb2.Token, _Mapping]] = ..., quote_token: _Optional[_Union[_token_pb2.Token, _Mapping]] = ...) -> None: ...



from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class TaxResidency(_message.Message):
    __slots__ = ("country_code", "tin")
    COUNTRY_CODE_FIELD_NUMBER: _ClassVar[int]
    TIN_FIELD_NUMBER: _ClassVar[int]
    country_code: str
    tin: str
    def __init__(self, country_code: _Optional[str] = ..., tin: _Optional[str] = ...) -> None: ...



import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from meshtrade.type.v1 import amount_pb2 as _amount_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FeeEntry(_message.Message):
    __slots__ = ("transaction_date", "transaction_id", "description", "amount", "reported_currency_value", "token_currency")
    TRANSACTION_DATE_FIELD_NUMBER: _ClassVar[int]
    TRANSACTION_ID_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    REPORTED_CURRENCY_VALUE_FIELD_NUMBER: _ClassVar[int]
    TOKEN_CURRENCY_FIELD_NUMBER: _ClassVar[int]
    transaction_date: _timestamp_pb2.Timestamp
    transaction_id: str
    description: str
    amount: _amount_pb2.Amount
    reported_currency_value: _amount_pb2.Amount
    token_currency: str
    def __init__(self, transaction_date: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., transaction_id: _Optional[str] = ..., description: _Optional[str] = ..., amount: _Optional[_Union[_amount_pb2.Amount, _Mapping]] = ..., reported_currency_value: _Optional[_Union[_amount_pb2.Amount, _Mapping]] = ..., token_currency: _Optional[str] = ...) -> None: ...



"""
This module provides helper functions for working with TimeOfDay protobuf messages.
"""

from datetime import datetime, timedelta
from datetime import time as python_time

from .date_pb2 import Date
from .time_of_day_pb2 import TimeOfDay


def new_time_of_day(hours: int = 0, minutes: int = 0, seconds: int = 0, nanos: int = 0) -> TimeOfDay:
    """Creates a new TimeOfDay from hours, minutes, seconds, and nanos values.

    Args:
        hours: Hours value (0-23, default 0)
        minutes: Minutes value (0-59, default 0)
        seconds: Seconds value (0-59, default 0)
        nanos: Nanoseconds value (0-999999999, default 0)

    Returns:
        A TimeOfDay protobuf message

    Raises:
        ValueError: If the time values are invalid
    """
    _validate_time_of_day(hours, minutes, seconds, nanos)
    return TimeOfDay(hours=hours, minutes=minutes, seconds=seconds, nanos=nanos)


def new_time_of_day_from_python_time(python_time_obj: python_time) -> TimeOfDay:
    """Creates a TimeOfDay from a Python time object.

    Args:
        python_time_obj: A Python datetime.time object

    Returns:
        A TimeOfDay protobuf message
    """
    return TimeOfDay(
        hours=python_time_obj.hour,
        minutes=python_time_obj.minute,
        seconds=python_time_obj.second,
        nanos=python_time_obj.microsecond * 1000,  # Convert microseconds to nanoseconds
    )


def new_time_of_day_from_datetime(datetime_obj: datetime) -> TimeOfDay:
    """Creates a TimeOfDay from a Python datetime object.
    Only extracts the time components, ignoring the date.

    Args:
        datetime_obj: A Python datetime.datetime object

    Returns:
        A TimeOfDay protobuf message
    """
    return new_time_of_day_from_python_time(datetime_obj.time())


def new_time_of_day_from_timedelta(delta: timedelta) -> TimeOfDay:
    """Creates a TimeOfDay from a timedelta representing time since midnight.

    Args:
        delta: A timedelta object representing time elapsed since midnight

    Returns:
        A TimeOfDay protobuf message

    Raises:
        ValueError: If the timedelta is negative or >= 24 hours
    """
    if delta.total_seconds() < 0:
        raise ValueError(f"Timedelta cannot be negative: {delta}")
    if delta.total_seconds() >= 24 * 3600:
        raise ValueError(f"Timedelta cannot be 24 hours or more: {delta}")

    total_seconds = int(delta.total_seconds())
    hours = total_seconds // 3600
    minutes = (total_seconds % 3600) // 60
    seconds = total_seconds % 60

    # Calculate nanoseconds from microseconds
    nanos = delta.microseconds * 1000

    return TimeOfDay(hours=hours, minutes=minutes, seconds=seconds, nanos=nanos)


def time_of_day_to_python_time(time_obj: TimeOfDay) -> python_time:
    """Converts a TimeOfDay protobuf message to a Python time object.

    Args:
        time_obj: A TimeOfDay protobuf message

    Returns:
        A Python datetime.time object

    Raises:
        ValueError: If the time is invalid or represents end of day (24:00:00)
    """
    if not time_obj:
        raise ValueError("TimeOfDay object is None")

    try:
        return python_time(
            hour=time_obj.hours,
            minute=time_obj.minutes,
            second=time_obj.seconds,
            microsecond=time_obj.nanos // 1000,  # Convert nanoseconds to microseconds
        )
    except ValueError as e:
        raise ValueError(f"Invalid time values: {e}") from e


def time_of_day_to_timedelta(time_obj: TimeOfDay) -> timedelta:
    """Converts a TimeOfDay to a timedelta representing time since midnight.

    Args:
        time_obj: A TimeOfDay protobuf message

    Returns:
        A timedelta object representing time elapsed since midnight
    """
    if not time_obj:
        return timedelta()

    return timedelta(
        hours=time_obj.hours,
        minutes=time_obj.minutes,
        seconds=time_obj.seconds,
        microseconds=time_obj.nanos // 1000,  # Convert nanoseconds to microseconds
    )


def time_of_day_to_datetime_with_date(time_obj: TimeOfDay, date_obj: Date) -> datetime:
    """Combines a TimeOfDay with a Date to create a datetime object.

    Args:
        time_obj: A TimeOfDay protobuf message
        date_obj: A Date protobuf message

    Returns:
        A Python datetime.datetime object

    Raises:
        ValueError: If either object is None/invalid or if date is incomplete
    """
    if not time_obj:
        raise ValueError("TimeOfDay object is None")
    if not date_obj:
        raise ValueError("Date object is None")

    # Import here to avoid circular imports
    from .date import date_is_complete

    if not date_is_complete(date_obj):
        raise ValueError("Date must be complete")

    try:
        return datetime(
            year=date_obj.year,
            month=date_obj.month,
            day=date_obj.day,
            hour=time_obj.hours,
            minute=time_obj.minutes,
            second=time_obj.seconds,
            microsecond=time_obj.nanos // 1000,  # Convert nanoseconds to microseconds
        )
    except ValueError as e:
        raise ValueError(f"Invalid datetime values: {e}") from e


def time_of_day_is_valid(time_obj: TimeOfDay | None) -> bool:
    """Checks if a TimeOfDay has valid values according to the protobuf constraints.

    Args:
        time_obj: A TimeOfDay protobuf message or None

    Returns:
        True if the time is valid, False otherwise
    """
    if not time_obj:
        return False

    try:
        _validate_time_of_day(time_obj.hours, time_obj.minutes, time_obj.seconds, time_obj.nanos)
        return True
    except ValueError:
        return False


def time_of_day_is_midnight(time_obj: TimeOfDay | None) -> bool:
    """Returns True if the time represents midnight (00:00:00.000000000).

    Args:
        time_obj: A TimeOfDay protobuf message or None

    Returns:
        True if the time is midnight, False otherwise
    """
    if not time_obj:
        return False
    return time_obj.hours == 0 and time_obj.minutes == 0 and time_obj.seconds == 0 and time_obj.nanos == 0


def time_of_day_to_string(time_obj: TimeOfDay | None) -> str:
    """Returns a string representation of the time in HH:MM:SS.nnnnnnnnn format.

    Args:
        time_obj: A TimeOfDay protobuf message or None

    Returns:
        String representation of the time
    """
    if not time_obj:
        return "<undefined>"

    if time_obj.nanos == 0:
        return f"{time_obj.hours:02d}:{time_obj.minutes:02d}:{time_obj.seconds:02d}"
    else:
        return f"{time_obj.hours:02d}:{time_obj.minutes:02d}:{time_obj.seconds:02d}.{time_obj.nanos:09d}"


def time_of_day_total_seconds(time_obj: TimeOfDay | None) -> float:
    """Returns the total number of seconds since midnight as a float.

    Args:
        time_obj: A TimeOfDay protobuf message or None

    Returns:
        Total seconds since midnight
    """
    if not time_obj:
        return 0.0

    return time_obj.hours * 3600 + time_obj.minutes * 60 + time_obj.seconds + time_obj.nanos / 1e9


def _validate_time_of_day(hours: int, minutes: int, seconds: int, nanos: int) -> None:
    """Validates the hours, minutes, seconds, and nanos values according to TimeOfDay constraints.

    Args:
        hours: Hours value
        minutes: Minutes value
        seconds: Seconds value
        nanos: Nanoseconds value

    Raises:
        ValueError: If the time values are invalid
    """
    # Hours validation
    if hours < 0 or hours > 23:
        raise ValueError(f"Hours must be between 0 and 23, got {hours}")

    # Minutes validation
    if minutes < 0 or minutes > 59:
        raise ValueError(f"Minutes must be between 0 and 59, got {minutes}")

    # Seconds validation
    if seconds < 0 or seconds > 59:
        raise ValueError(f"Seconds must be between 0 and 59, got {seconds}")

    # Nanos validation
    if nanos < 0 or nanos > 999999999:
        raise ValueError(f"Nanos must be between 0 and 999,999,999, got {nanos}")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/iam/api_user/v1/api_user.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/iam/api_user/v1/api_user.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(meshtrade/iam/api_user/v1/api_user.proto\x12\x19meshtrade.iam.api_user.v1\x1a\x1b\x62uf/validate/validate.proto\"\x80\x07\n\x07\x41PIUser\x12\xca\x01\n\x04name\x18\x01 \x01(\tB\xb5\x01\xbaH\xb1\x01\xba\x01\xad\x01\n\x14name.format.optional\x12:name must be empty or in the format iam/api_users/{ULIDv2}\x1aYsize(this) == 0 || this.matches(\'^iam/api_users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')R\x04name\x12R\n\x05owner\x18\x02 \x01(\tB<\xbaH9r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01!\xc8\x01\x01R\x05owner\x12V\n\x06owners\x18\x03 \x03(\tB>\xbaH;\x92\x01\x38\"6r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01!R\x06owners\x12\xb4\x01\n\x0c\x64isplay_name\x18\x04 \x01(\tB\x90\x01\xbaH\x8c\x01r\x05\x10\x01\x18\xff\x01\xba\x01\x7f\n\x15\x64isplay_name.required\x12\x41\x64isplay name is required and must be between 1 and 255 characters\x1a#size(this) > 0 && size(this) <= 255\xc8\x01\x01R\x0b\x64isplayName\x12\xbe\x01\n\x05state\x18\x05 \x01(\x0e\x32\'.meshtrade.iam.api_user.v1.APIUserStateB\x7f\xbaH|\x82\x01\x02\x10\x01\xba\x01t\n\x0bstate.valid\x12/state must be a valid APIUserState if specified\x1a\x34int(this) == 0 || (int(this) >= 1 && int(this) <= 2)R\x05state\x12k\n\x05roles\x18\x06 \x03(\tBU\xbaHR\x92\x01O\"MrK\x10/\x18\x30\x32\x45^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}/roles/[1-9][0-9]{6,7}$R\x05roles\x12\x17\n\x07\x61pi_key\x18\x07 \x01(\tR\x06\x61piKey*f\n\x0c\x41PIUserState\x12\x1e\n\x1a\x41PI_USER_STATE_UNSPECIFIED\x10\x00\x12\x19\n\x15\x41PI_USER_STATE_ACTIVE\x10\x01\x12\x1b\n\x17\x41PI_USER_STATE_INACTIVE\x10\x02*\xa6\x01\n\rAPIUserAction\x12\x1f\n\x1b\x41PI_USER_ACTION_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x41PI_USER_ACTION_ACTIVATE\x10\x01\x12\x1e\n\x1a\x41PI_USER_ACTION_DEACTIVATE\x10\x02\x12\x1a\n\x16\x41PI_USER_ACTION_CREATE\x10\x03\x12\x1a\n\x16\x41PI_USER_ACTION_UPDATE\x10\x04\x42n\n co.meshtrade.api.iam.api_user.v1B\x11\x41piUserOuterClassZ7github.com/meshtrade/api/go/iam/api_user/v1;api_user_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.iam.api_user.v1.api_user_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n co.meshtrade.api.iam.api_user.v1B\021ApiUserOuterClassZ7github.com/meshtrade/api/go/iam/api_user/v1;api_user_v1'
  _globals['_APIUSER'].fields_by_name['name']._loaded_options = None
  _globals['_APIUSER'].fields_by_name['name']._serialized_options = b'\272H\261\001\272\001\255\001\n\024name.format.optional\022:name must be empty or in the format iam/api_users/{ULIDv2}\032Ysize(this) == 0 || this.matches(\'^iam/api_users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')'
  _globals['_APIUSER'].fields_by_name['owner']._loaded_options = None
  _globals['_APIUSER'].fields_by_name['owner']._serialized_options = b'\272H9r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001!\310\001\001'
  _globals['_APIUSER'].fields_by_name['owners']._loaded_options = None
  _globals['_APIUSER'].fields_by_name['owners']._serialized_options = b'\272H;\222\0018\"6r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001!'
  _globals['_APIUSER'].fields_by_name['display_name']._loaded_options = None
  _globals['_APIUSER'].fields_by_name['display_name']._serialized_options = b'\272H\214\001r\005\020\001\030\377\001\272\001\177\n\025display_name.required\022Adisplay name is required and must be between 1 and 255 characters\032#size(this) > 0 && size(this) <= 255\310\001\001'
  _globals['_APIUSER'].fields_by_name['state']._loaded_options = None
  _globals['_APIUSER'].fields_by_name['state']._serialized_options = b'\272H|\202\001\002\020\001\272\001t\n\013state.valid\022/state must be a valid APIUserState if specified\0324int(this) == 0 || (int(this) >= 1 && int(this) <= 2)'
  _globals['_APIUSER'].fields_by_name['roles']._loaded_options = None
  _globals['_APIUSER'].fields_by_name['roles']._serialized_options = b'\272HR\222\001O\"MrK\020/\03002E^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}/roles/[1-9][0-9]{6,7}$'
  _globals['_APIUSERSTATE']._serialized_start=999
  _globals['_APIUSERSTATE']._serialized_end=1101
  _globals['_APIUSERACTION']._serialized_start=1104
  _globals['_APIUSERACTION']._serialized_end=1270
  _globals['_APIUSER']._serialized_start=101
  _globals['_APIUSER']._serialized_end=997
# @@protoc_insertion_point(module_scope)



import datetime

from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from meshtrade.iam.user_profile.v1 import user_profile_pb2 as _user_profile_pb2
from meshtrade.option.method_options.v1 import method_options_pb2 as _method_options_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetUserProfileByUserRequest(_message.Message):
    __slots__ = ("user",)
    USER_FIELD_NUMBER: _ClassVar[int]
    user: str
    def __init__(self, user: _Optional[str] = ...) -> None: ...

class UpdateUserProfileRequest(_message.Message):
    __slots__ = ("user_profile",)
    USER_PROFILE_FIELD_NUMBER: _ClassVar[int]
    user_profile: _user_profile_pb2.UserProfile
    def __init__(self, user_profile: _Optional[_Union[_user_profile_pb2.UserProfile, _Mapping]] = ...) -> None: ...

class GetUserProfileRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class ListUserProfilesRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListUserProfilesResponse(_message.Message):
    __slots__ = ("user_profiles",)
    USER_PROFILES_FIELD_NUMBER: _ClassVar[int]
    user_profiles: _containers.RepeatedCompositeFieldContainer[_user_profile_pb2.UserProfile]
    def __init__(self, user_profiles: _Optional[_Iterable[_Union[_user_profile_pb2.UserProfile, _Mapping]]] = ...) -> None: ...

class GetUserProfilePictureUploadUrlRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class GetUserProfilePictureUploadUrlResponse(_message.Message):
    __slots__ = ("upload_url", "expires_at")
    UPLOAD_URL_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    upload_url: str
    expires_at: _timestamp_pb2.Timestamp
    def __init__(self, upload_url: _Optional[str] = ..., expires_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class SortingOrder(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SORTING_ORDER_UNSPECIFIED: _ClassVar[SortingOrder]
    SORTING_ORDER_ASC: _ClassVar[SortingOrder]
    SORTING_ORDER_DESC: _ClassVar[SortingOrder]
SORTING_ORDER_UNSPECIFIED: SortingOrder
SORTING_ORDER_ASC: SortingOrder
SORTING_ORDER_DESC: SortingOrder



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/testing/ledger/token_tap/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/testing/ledger/token_tap/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from meshtrade.option.method_options.v1 import method_options_pb2 as meshtrade_dot_option_dot_method__options_dot_v1_dot_method__options__pb2
from meshtrade.testing.ledger.token_tap.v1 import option_pb2 as meshtrade_dot_testing_dot_ledger_dot_token__tap_dot_v1_dot_option__pb2
from meshtrade.type.v1 import amount_pb2 as meshtrade_dot_type_dot_v1_dot_amount__pb2
from meshtrade.type.v1 import token_pb2 as meshtrade_dot_type_dot_v1_dot_token__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3meshtrade/testing/ledger/token_tap/v1/service.proto\x12%meshtrade.testing.ledger.token_tap.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x37meshtrade/option/method_options/v1/method_options.proto\x1a\x32meshtrade/testing/ledger/token_tap/v1/option.proto\x1a\x1emeshtrade/type/v1/amount.proto\x1a\x1dmeshtrade/type/v1/token.proto\"\x1c\n\x1aInitialiseTokenTapsRequest\"\x1d\n\x1bInitialiseTokenTapsResponse\"\x16\n\x14ListTokenTapsRequest\"I\n\x15ListTokenTapsResponse\x12\x30\n\x06tokens\x18\x01 \x03(\x0b\x32\x18.meshtrade.type.v1.TokenR\x06tokens\"\xc2\x01\n\x10MintTokenRequest\x12\x39\n\x06\x61mount\x18\x01 \x01(\x0b\x32\x19.meshtrade.type.v1.AmountB\x06\xbaH\x03\xc8\x01\x01R\x06\x61mount\x12 \n\x07\x61\x64\x64ress\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x07\x61\x64\x64ress\x12Q\n\x07options\x18\x03 \x01(\x0b\x32\x37.meshtrade.testing.ledger.token_tap.v1.MintTokenOptionsR\x07options\"\x13\n\x11MintTokenResponse2\xdc\x03\n\x0fTokenTapService\x12\xa6\x01\n\x13InitialiseTokenTaps\x12\x41.meshtrade.testing.ledger.token_tap.v1.InitialiseTokenTapsRequest\x1a\x42.meshtrade.testing.ledger.token_tap.v1.InitialiseTokenTapsResponse\"\x08\xb2\xb5\x18\x04\x08\x02\x10\x01\x12\x94\x01\n\rListTokenTaps\x12;.meshtrade.testing.ledger.token_tap.v1.ListTokenTapsRequest\x1a<.meshtrade.testing.ledger.token_tap.v1.ListTokenTapsResponse\"\x08\xb2\xb5\x18\x04\x08\x01\x10\x01\x12\x88\x01\n\tMintToken\x12\x37.meshtrade.testing.ledger.token_tap.v1.MintTokenRequest\x1a\x38.meshtrade.testing.ledger.token_tap.v1.MintTokenResponse\"\x08\xb2\xb5\x18\x04\x08\x02\x10\x01\x42t\n,co.meshtrade.api.testing.ledger.token_tap.v1ZDgithub.com/meshtrade/api/go/testing/ledger/token_tap/v1;token_tap_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.testing.ledger.token_tap.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n,co.meshtrade.api.testing.ledger.token_tap.v1ZDgithub.com/meshtrade/api/go/testing/ledger/token_tap/v1;token_tap_v1'
  _globals['_MINTTOKENREQUEST'].fields_by_name['amount']._loaded_options = None
  _globals['_MINTTOKENREQUEST'].fields_by_name['amount']._serialized_options = b'\272H\003\310\001\001'
  _globals['_MINTTOKENREQUEST'].fields_by_name['address']._loaded_options = None
  _globals['_MINTTOKENREQUEST'].fields_by_name['address']._serialized_options = b'\272H\003\310\001\001'
  _globals['_TOKENTAPSERVICE'].methods_by_name['InitialiseTokenTaps']._loaded_options = None
  _globals['_TOKENTAPSERVICE'].methods_by_name['InitialiseTokenTaps']._serialized_options = b'\262\265\030\004\010\002\020\001'
  _globals['_TOKENTAPSERVICE'].methods_by_name['ListTokenTaps']._loaded_options = None
  _globals['_TOKENTAPSERVICE'].methods_by_name['ListTokenTaps']._serialized_options = b'\262\265\030\004\010\001\020\001'
  _globals['_TOKENTAPSERVICE'].methods_by_name['MintToken']._loaded_options = None
  _globals['_TOKENTAPSERVICE'].methods_by_name['MintToken']._serialized_options = b'\262\265\030\004\010\002\020\001'
  _globals['_INITIALISETOKENTAPSREQUEST']._serialized_start=295
  _globals['_INITIALISETOKENTAPSREQUEST']._serialized_end=323
  _globals['_INITIALISETOKENTAPSRESPONSE']._serialized_start=325
  _globals['_INITIALISETOKENTAPSRESPONSE']._serialized_end=354
  _globals['_LISTTOKENTAPSREQUEST']._serialized_start=356
  _globals['_LISTTOKENTAPSREQUEST']._serialized_end=378
  _globals['_LISTTOKENTAPSRESPONSE']._serialized_start=380
  _globals['_LISTTOKENTAPSRESPONSE']._serialized_end=453
  _globals['_MINTTOKENREQUEST']._serialized_start=456
  _globals['_MINTTOKENREQUEST']._serialized_end=650
  _globals['_MINTTOKENRESPONSE']._serialized_start=652
  _globals['_MINTTOKENRESPONSE']._serialized_end=671
  _globals['_TOKENTAPSERVICE']._serialized_start=674
  _globals['_TOKENTAPSERVICE']._serialized_end=1150
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/compliance/client/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/compliance/client/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from meshtrade.compliance.client.v1 import client_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_client__pb2
from meshtrade.option.method_options.v1 import method_options_pb2 as meshtrade_dot_option_dot_method__options_dot_v1_dot_method__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,meshtrade/compliance/client/v1/service.proto\x12\x1emeshtrade.compliance.client.v1\x1a\x1b\x62uf/validate/validate.proto\x1a+meshtrade/compliance/client/v1/client.proto\x1a\x37meshtrade/option/method_options/v1/method_options.proto\"e\n\x10GetClientRequest\x12Q\n\x04name\x18\x01 \x01(\tB=\xbaH:r520^clients/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01!\xc8\x01\x01R\x04name\"]\n\x13\x43reateClientRequest\x12\x46\n\x06\x63lient\x18\x01 \x01(\x0b\x32&.meshtrade.compliance.client.v1.ClientB\x06\xbaH\x03\xc8\x01\x01R\x06\x63lient\"k\n\x15GetGroupClientRequest\x12R\n\x05group\x18\x01 \x01(\tB<\xbaH9r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01!\xc8\x01\x01R\x05group\"\x14\n\x12ListClientsRequest\"W\n\x13ListClientsResponse\x12@\n\x07\x63lients\x18\x01 \x03(\x0b\x32&.meshtrade.compliance.client.v1.ClientR\x07\x63lients2\xa8\x04\n\rClientService\x12}\n\x0c\x43reateClient\x12\x33.meshtrade.compliance.client.v1.CreateClientRequest\x1a&.meshtrade.compliance.client.v1.Client\"\x10\xb2\xb5\x18\x0c\x08\x02\x10\x02\x1a\x06\x80\x89z\x82\x89z\x12}\n\tGetClient\x12\x30.meshtrade.compliance.client.v1.GetClientRequest\x1a&.meshtrade.compliance.client.v1.Client\"\x16\xb2\xb5\x18\x12\x08\x01\x10\x02\x1a\x0c\x80\x89z\x81\x89z\x82\x89z\x83\x89z\x12\x87\x01\n\x0eGetGroupClient\x12\x35.meshtrade.compliance.client.v1.GetGroupClientRequest\x1a&.meshtrade.compliance.client.v1.Client\"\x16\xb2\xb5\x18\x12\x08\x01\x10\x02\x1a\x0c\x80\x89z\x81\x89z\x82\x89z\x83\x89z\x12\x8e\x01\n\x0bListClients\x12\x32.meshtrade.compliance.client.v1.ListClientsRequest\x1a\x33.meshtrade.compliance.client.v1.ListClientsResponse\"\x16\xb2\xb5\x18\x12\x08\x01\x10\x02\x1a\x0c\x80\x89z\x81\x89z\x82\x89z\x83\x89zBc\n%co.meshtrade.api.compliance.client.v1Z:github.com/meshtrade/api/go/compliance/client/v1;client_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.compliance.client.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%co.meshtrade.api.compliance.client.v1Z:github.com/meshtrade/api/go/compliance/client/v1;client_v1'
  _globals['_GETCLIENTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETCLIENTREQUEST'].fields_by_name['name']._serialized_options = b'\272H:r520^clients/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001!\310\001\001'
  _globals['_CREATECLIENTREQUEST'].fields_by_name['client']._loaded_options = None
  _globals['_CREATECLIENTREQUEST'].fields_by_name['client']._serialized_options = b'\272H\003\310\001\001'
  _globals['_GETGROUPCLIENTREQUEST'].fields_by_name['group']._loaded_options = None
  _globals['_GETGROUPCLIENTREQUEST'].fields_by_name['group']._serialized_options = b'\272H9r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001!\310\001\001'
  _globals['_CLIENTSERVICE'].methods_by_name['CreateClient']._loaded_options = None
  _globals['_CLIENTSERVICE'].methods_by_name['CreateClient']._serialized_options = b'\262\265\030\014\010\002\020\002\032\006\200\211z\202\211z'
  _globals['_CLIENTSERVICE'].methods_by_name['GetClient']._loaded_options = None
  _globals['_CLIENTSERVICE'].methods_by_name['GetClient']._serialized_options = b'\262\265\030\022\010\001\020\002\032\014\200\211z\201\211z\202\211z\203\211z'
  _globals['_CLIENTSERVICE'].methods_by_name['GetGroupClient']._loaded_options = None
  _globals['_CLIENTSERVICE'].methods_by_name['GetGroupClient']._serialized_options = b'\262\265\030\022\010\001\020\002\032\014\200\211z\201\211z\202\211z\203\211z'
  _globals['_CLIENTSERVICE'].methods_by_name['ListClients']._loaded_options = None
  _globals['_CLIENTSERVICE'].methods_by_name['ListClients']._serialized_options = b'\262\265\030\022\010\001\020\002\032\014\200\211z\201\211z\202\211z\203\211z'
  _globals['_GETCLIENTREQUEST']._serialized_start=211
  _globals['_GETCLIENTREQUEST']._serialized_end=312
  _globals['_CREATECLIENTREQUEST']._serialized_start=314
  _globals['_CREATECLIENTREQUEST']._serialized_end=407
  _globals['_GETGROUPCLIENTREQUEST']._serialized_start=409
  _globals['_GETGROUPCLIENTREQUEST']._serialized_end=516
  _globals['_LISTCLIENTSREQUEST']._serialized_start=518
  _globals['_LISTCLIENTSREQUEST']._serialized_end=538
  _globals['_LISTCLIENTSRESPONSE']._serialized_start=540
  _globals['_LISTCLIENTSRESPONSE']._serialized_end=627
  _globals['_CLIENTSERVICE']._serialized_start=630
  _globals['_CLIENTSERVICE']._serialized_end=1182
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class PepStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    PEP_STATUS_UNSPECIFIED: _ClassVar[PepStatus]
    PEP_STATUS_IS_NOT_PEP: _ClassVar[PepStatus]
    PEP_STATUS_IS_PEP: _ClassVar[PepStatus]
    PEP_STATUS_IS_ASSOCIATE: _ClassVar[PepStatus]
PEP_STATUS_UNSPECIFIED: PepStatus
PEP_STATUS_IS_NOT_PEP: PepStatus
PEP_STATUS_IS_PEP: PepStatus
PEP_STATUS_IS_ASSOCIATE: PepStatus



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/iam/user_profile/v1/user_profile.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/iam/user_profile/v1/user_profile.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from meshtrade.type.v1 import token_pb2 as meshtrade_dot_type_dot_v1_dot_token__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0meshtrade/iam/user_profile/v1/user_profile.proto\x12\x1dmeshtrade.iam.user_profile.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1dmeshtrade/type/v1/token.proto\"\xaf\n\n\x0bUserProfile\x12\xd2\x01\n\x04name\x18\x01 \x01(\tB\xbd\x01\xbaH\xb9\x01\xba\x01\xb5\x01\n\x14name.format.optional\x12>name must be empty or in the format iam/user_profiles/{ULIDv2}\x1a]size(this) == 0 || this.matches(\'^iam/user_profiles/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')R\x04name\x12R\n\x05owner\x18\x02 \x01(\tB<\xbaH9r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01!\xc8\x01\x01R\x05owner\x12V\n\x06owners\x18\x03 \x03(\tB>\xbaH;\x92\x01\x38\"6r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01!R\x06owners\x12\xdf\x02\n\x04user\x18\x04 \x01(\tB\xca\x02\xbaH\xc6\x02r32.^users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01 \xba\x01V\n\ruser.required\x12\x35user is required and must be in format users/{ULIDv2}\x1a\x0esize(this) > 0\xba\x01\xb1\x01\n\x0buser.format\x12\x62user must be in format users/{ULIDv2} where ULIDv2 is exactly 26 uppercase alphanumeric characters\x1a>this.matches(\'^users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')\xc8\x01\x01R\x04user\x12\xdb\x01\n\x06locale\x18\x05 \x01(\tB\xc2\x01\xbaH\xbe\x01\xba\x01\xba\x01\n\rlocale.format\x12Rlocale must be empty or a valid BCP 47 language tag (e.g., \'en\', \'en-US\', \'fr-FR\')\x1aUsize(this) == 0 || this.matches(\'^[a-z]{2,3}(-[A-Za-z]{4})?(-([A-Z]{2}|[0-9]{3}))?$\')R\x06locale\x12\xa5\x01\n\x13profile_picture_url\x18\x06 \x01(\tBu\xbaHr\xba\x01o\n\x1aprofile_picture_url.format\x12\x30profile_picture_url must be empty or a valid URI\x1a\x1fsize(this) == 0 || this.isUri()R\x11profilePictureUrl\x12)\n\x0c\x64isplay_name\x18\x07 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x0b\x64isplayName\x12\x43\n\x10\x64isplay_currency\x18\x08 \x01(\x0b\x32\x18.meshtrade.type.v1.TokenR\x0f\x64isplayCurrency\x12G\n\x12reporting_currency\x18\t \x01(\x0b\x32\x18.meshtrade.type.v1.TokenR\x11reportingCurrencyBg\n$co.meshtrade.api.iam.user_profile.v1Z?github.com/meshtrade/api/go/iam/user_profile/v1;user_profile_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.iam.user_profile.v1.user_profile_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$co.meshtrade.api.iam.user_profile.v1Z?github.com/meshtrade/api/go/iam/user_profile/v1;user_profile_v1'
  _globals['_USERPROFILE'].fields_by_name['name']._loaded_options = None
  _globals['_USERPROFILE'].fields_by_name['name']._serialized_options = b'\272H\271\001\272\001\265\001\n\024name.format.optional\022>name must be empty or in the format iam/user_profiles/{ULIDv2}\032]size(this) == 0 || this.matches(\'^iam/user_profiles/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')'
  _globals['_USERPROFILE'].fields_by_name['owner']._loaded_options = None
  _globals['_USERPROFILE'].fields_by_name['owner']._serialized_options = b'\272H9r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001!\310\001\001'
  _globals['_USERPROFILE'].fields_by_name['owners']._loaded_options = None
  _globals['_USERPROFILE'].fields_by_name['owners']._serialized_options = b'\272H;\222\0018\"6r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001!'
  _globals['_USERPROFILE'].fields_by_name['user']._loaded_options = None
  _globals['_USERPROFILE'].fields_by_name['user']._serialized_options = b'\272H\306\002r32.^users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001 \272\001V\n\ruser.required\0225user is required and must be in format users/{ULIDv2}\032\016size(this) > 0\272\001\261\001\n\013user.format\022buser must be in format users/{ULIDv2} where ULIDv2 is exactly 26 uppercase alphanumeric characters\032>this.matches(\'^users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')\310\001\001'
  _globals['_USERPROFILE'].fields_by_name['locale']._loaded_options = None
  _globals['_USERPROFILE'].fields_by_name['locale']._serialized_options = b'\272H\276\001\272\001\272\001\n\rlocale.format\022Rlocale must be empty or a valid BCP 47 language tag (e.g., \'en\', \'en-US\', \'fr-FR\')\032Usize(this) == 0 || this.matches(\'^[a-z]{2,3}(-[A-Za-z]{4})?(-([A-Z]{2}|[0-9]{3}))?$\')'
  _globals['_USERPROFILE'].fields_by_name['profile_picture_url']._loaded_options = None
  _globals['_USERPROFILE'].fields_by_name['profile_picture_url']._serialized_options = b'\272Hr\272\001o\n\032profile_picture_url.format\0220profile_picture_url must be empty or a valid URI\032\037size(this) == 0 || this.isUri()'
  _globals['_USERPROFILE'].fields_by_name['display_name']._loaded_options = None
  _globals['_USERPROFILE'].fields_by_name['display_name']._serialized_options = b'\272H\003\310\001\001'
  _globals['_USERPROFILE']._serialized_start=144
  _globals['_USERPROFILE']._serialized_end=1471
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MintTokenOptions(_message.Message):
    __slots__ = ("stellar_mint_options",)
    STELLAR_MINT_OPTIONS_FIELD_NUMBER: _ClassVar[int]
    stellar_mint_options: StellarMintOptions
    def __init__(self, stellar_mint_options: _Optional[_Union[StellarMintOptions, _Mapping]] = ...) -> None: ...

class StellarMintOptions(_message.Message):
    __slots__ = ("options",)
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    options: _containers.RepeatedCompositeFieldContainer[StellarMintOption]
    def __init__(self, options: _Optional[_Iterable[_Union[StellarMintOption, _Mapping]]] = ...) -> None: ...

class StellarMintOption(_message.Message):
    __slots__ = ("stellar_mint_token_with_memo",)
    STELLAR_MINT_TOKEN_WITH_MEMO_FIELD_NUMBER: _ClassVar[int]
    stellar_mint_token_with_memo: StellarMintTokenWithMemo
    def __init__(self, stellar_mint_token_with_memo: _Optional[_Union[StellarMintTokenWithMemo, _Mapping]] = ...) -> None: ...

class StellarMintTokenWithMemo(_message.Message):
    __slots__ = ("memo",)
    MEMO_FIELD_NUMBER: _ClassVar[int]
    memo: str
    def __init__(self, memo: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/option/method_options/v1/method_options.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/option/method_options/v1/method_options.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from meshtrade.iam.role.v1 import role_pb2 as meshtrade_dot_iam_dot_role_dot_v1_dot_role__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7meshtrade/option/method_options/v1/method_options.proto\x12\"meshtrade.option.method_options.v1\x1a google/protobuf/descriptor.proto\x1a meshtrade/iam/role/v1/role.proto\"\xc9\x02\n\rMethodOptions\x12\x42\n\x04type\x18\x01 \x01(\x0e\x32..meshtrade.option.method_options.v1.MethodTypeR\x04type\x12X\n\x0c\x61\x63\x63\x65ss_level\x18\x02 \x01(\x0e\x32\x35.meshtrade.option.method_options.v1.MethodAccessLevelR\x0b\x61\x63\x63\x65ssLevel\x12\x31\n\x05roles\x18\x03 \x03(\x0e\x32\x1b.meshtrade.iam.role.v1.RoleR\x05roles\x12g\n\x13verification_status\x18\x04 \x01(\x0e\x32\x36.meshtrade.option.method_options.v1.VerificationStatusR\x12verificationStatus*V\n\nMethodType\x12\x1b\n\x17METHOD_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10METHOD_TYPE_READ\x10\x01\x12\x15\n\x11METHOD_TYPE_WRITE\x10\x02*|\n\x11MethodAccessLevel\x12#\n\x1fMETHOD_ACCESS_LEVEL_UNSPECIFIED\x10\x00\x12\x1e\n\x1aMETHOD_ACCESS_LEVEL_PUBLIC\x10\x01\x12\"\n\x1eMETHOD_ACCESS_LEVEL_AUTHORISED\x10\x02*[\n\x12VerificationStatus\x12#\n\x1fVERIFICATION_STATUS_UNSPECIFIED\x10\x00\x12 \n\x1cVERIFICATION_STATUS_VERIFIED\x10\x01:z\n\x0emethod_options\x12\x1e.google.protobuf.MethodOptions\x18\xd6\x86\x03 \x01(\x0b\x32\x31.meshtrade.option.method_options.v1.MethodOptionsR\rmethodOptionsBs\n)co.meshtrade.api.option.method_options.v1ZFgithub.com/meshtrade/api/go/option/method_options/v1;method_options_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.option.method_options.v1.method_options_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)co.meshtrade.api.option.method_options.v1ZFgithub.com/meshtrade/api/go/option/method_options/v1;method_options_v1'
  _globals['_METHODTYPE']._serialized_start=495
  _globals['_METHODTYPE']._serialized_end=581
  _globals['_METHODACCESSLEVEL']._serialized_start=583
  _globals['_METHODACCESSLEVEL']._serialized_end=707
  _globals['_VERIFICATIONSTATUS']._serialized_start=709
  _globals['_VERIFICATIONSTATUS']._serialized_end=800
  _globals['_METHODOPTIONS']._serialized_start=164
  _globals['_METHODOPTIONS']._serialized_end=493
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/compliance/client/v1/industry_classification.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/compliance/client/v1/industry_classification.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<meshtrade/compliance/client/v1/industry_classification.proto\x12\x1emeshtrade.compliance.client.v1\"\xdc\x02\n\x16IndustryClassification\x12\x1f\n\x0bsector_code\x18\x01 \x01(\tR\nsectorCode\x12\x1f\n\x0bsector_name\x18\x02 \x01(\tR\nsectorName\x12.\n\x13industry_group_code\x18\x03 \x01(\tR\x11industryGroupCode\x12.\n\x13industry_group_name\x18\x04 \x01(\tR\x11industryGroupName\x12#\n\rindustry_code\x18\x05 \x01(\tR\x0cindustryCode\x12#\n\rindustry_name\x18\x06 \x01(\tR\x0cindustryName\x12*\n\x11sub_industry_code\x18\x07 \x01(\tR\x0fsubIndustryCode\x12*\n\x11sub_industry_name\x18\x08 \x01(\tR\x0fsubIndustryNameBc\n%co.meshtrade.api.compliance.client.v1Z:github.com/meshtrade/api/go/compliance/client/v1;client_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.compliance.client.v1.industry_classification_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%co.meshtrade.api.compliance.client.v1Z:github.com/meshtrade/api/go/compliance/client/v1;client_v1'
  _globals['_INDUSTRYCLASSIFICATION']._serialized_start=97
  _globals['_INDUSTRYCLASSIFICATION']._serialized_end=445
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/compliance/client/v1/natural_person_connection_type.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/compliance/client/v1/natural_person_connection_type.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmeshtrade/compliance/client/v1/natural_person_connection_type.proto\x12\x1emeshtrade.compliance.client.v1*\xb4\x06\n\x1bNaturalPersonConnectionType\x12.\n*NATURAL_PERSON_CONNECTION_TYPE_UNSPECIFIED\x10\x00\x12<\n8NATURAL_PERSON_CONNECTION_TYPE_ULTIMATE_BENEFICIAL_OWNER\x10\x01\x12.\n*NATURAL_PERSON_CONNECTION_TYPE_SHAREHOLDER\x10\x02\x12+\n\'NATURAL_PERSON_CONNECTION_TYPE_DIRECTOR\x10\x03\x12\x34\n0NATURAL_PERSON_CONNECTION_TYPE_SENIOR_MANAGEMENT\x10\x04\x12\x37\n3NATURAL_PERSON_CONNECTION_TYPE_AUTHORIZED_SIGNATORY\x10\x05\x12*\n&NATURAL_PERSON_CONNECTION_TYPE_FOUNDER\x10\x06\x12)\n%NATURAL_PERSON_CONNECTION_TYPE_SPOUSE\x10\x14\x12\x33\n/NATURAL_PERSON_CONNECTION_TYPE_DOMESTIC_PARTNER\x10\x15\x12)\n%NATURAL_PERSON_CONNECTION_TYPE_PARENT\x10\x16\x12(\n$NATURAL_PERSON_CONNECTION_TYPE_CHILD\x10\x17\x12*\n&NATURAL_PERSON_CONNECTION_TYPE_SIBLING\x10\x18\x12\x33\n/NATURAL_PERSON_CONNECTION_TYPE_BUSINESS_PARTNER\x10\x1e\x12\x32\n.NATURAL_PERSON_CONNECTION_TYPE_CLOSE_ASSOCIATE\x10\x1f\x12,\n(NATURAL_PERSON_CONNECTION_TYPE_GUARANTOR\x10 \x12\x37\n3NATURAL_PERSON_CONNECTION_TYPE_BENEFICIARY_OF_TRUST\x10!Bc\n%co.meshtrade.api.compliance.client.v1Z:github.com/meshtrade/api/go/compliance/client/v1;client_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.compliance.client.v1.natural_person_connection_type_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%co.meshtrade.api.compliance.client.v1Z:github.com/meshtrade/api/go/compliance/client/v1;client_v1'
  _globals['_NATURALPERSONCONNECTIONTYPE']._serialized_start=104
  _globals['_NATURALPERSONCONNECTIONTYPE']._serialized_end=924
# @@protoc_insertion_point(module_scope)



import datetime

from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from meshtrade.type.v1 import amount_pb2 as _amount_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LimitOrderSide(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    LIMIT_ORDER_SIDE_UNSPECIFIED: _ClassVar[LimitOrderSide]
    LIMIT_ORDER_SIDE_BUY: _ClassVar[LimitOrderSide]
    LIMIT_ORDER_SIDE_SELL: _ClassVar[LimitOrderSide]

class LimitOrderState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    LIMIT_ORDER_STATE_UNSPECIFIED: _ClassVar[LimitOrderState]
    LIMIT_ORDER_STATE_SUBMISSION_IN_PROGRESS: _ClassVar[LimitOrderState]
    LIMIT_ORDER_STATE_SUBMISSION_FAILED: _ClassVar[LimitOrderState]
    LIMIT_ORDER_STATE_OPEN: _ClassVar[LimitOrderState]
    LIMIT_ORDER_STATE_COMPLETE_IN_PROGRESS: _ClassVar[LimitOrderState]
    LIMIT_ORDER_STATE_COMPLETE: _ClassVar[LimitOrderState]
    LIMIT_ORDER_STATE_CANCELLATION_IN_PROGRESS: _ClassVar[LimitOrderState]
    LIMIT_ORDER_STATE_CANCELLED: _ClassVar[LimitOrderState]
LIMIT_ORDER_SIDE_UNSPECIFIED: LimitOrderSide
LIMIT_ORDER_SIDE_BUY: LimitOrderSide
LIMIT_ORDER_SIDE_SELL: LimitOrderSide
LIMIT_ORDER_STATE_UNSPECIFIED: LimitOrderState
LIMIT_ORDER_STATE_SUBMISSION_IN_PROGRESS: LimitOrderState
LIMIT_ORDER_STATE_SUBMISSION_FAILED: LimitOrderState
LIMIT_ORDER_STATE_OPEN: LimitOrderState
LIMIT_ORDER_STATE_COMPLETE_IN_PROGRESS: LimitOrderState
LIMIT_ORDER_STATE_COMPLETE: LimitOrderState
LIMIT_ORDER_STATE_CANCELLATION_IN_PROGRESS: LimitOrderState
LIMIT_ORDER_STATE_CANCELLED: LimitOrderState

class LimitOrder(_message.Message):
    __slots__ = ("name", "owner", "owners", "account", "external_reference", "side", "limit_price", "quantity", "fill_price", "filled_quantity", "state", "number", "submitted_at")
    NAME_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    OWNERS_FIELD_NUMBER: _ClassVar[int]
    ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_REFERENCE_FIELD_NUMBER: _ClassVar[int]
    SIDE_FIELD_NUMBER: _ClassVar[int]
    LIMIT_PRICE_FIELD_NUMBER: _ClassVar[int]
    QUANTITY_FIELD_NUMBER: _ClassVar[int]
    FILL_PRICE_FIELD_NUMBER: _ClassVar[int]
    FILLED_QUANTITY_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    SUBMITTED_AT_FIELD_NUMBER: _ClassVar[int]
    name: str
    owner: str
    owners: _containers.RepeatedScalarFieldContainer[str]
    account: str
    external_reference: str
    side: LimitOrderSide
    limit_price: _amount_pb2.Amount
    quantity: _amount_pb2.Amount
    fill_price: _amount_pb2.Amount
    filled_quantity: _amount_pb2.Amount
    state: LimitOrderState
    number: str
    submitted_at: _timestamp_pb2.Timestamp
    def __init__(self, name: _Optional[str] = ..., owner: _Optional[str] = ..., owners: _Optional[_Iterable[str]] = ..., account: _Optional[str] = ..., external_reference: _Optional[str] = ..., side: _Optional[_Union[LimitOrderSide, str]] = ..., limit_price: _Optional[_Union[_amount_pb2.Amount, _Mapping]] = ..., quantity: _Optional[_Union[_amount_pb2.Amount, _Mapping]] = ..., fill_price: _Optional[_Union[_amount_pb2.Amount, _Mapping]] = ..., filled_quantity: _Optional[_Union[_amount_pb2.Amount, _Mapping]] = ..., state: _Optional[_Union[LimitOrderState, str]] = ..., number: _Optional[str] = ..., submitted_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



"""Income entry utility functions."""

from meshtrade.reporting.account_report.v1.income_entry_pb2 import IncomeNarrative


def income_narrative_pretty_string(narrative: IncomeNarrative) -> str:
    """Generate human-readable string for income narrative.

    Converts enum values to concise, display-friendly strings suitable for
    reports and user interfaces.

    Args:
        narrative: IncomeNarrative enum value

    Returns:
        Pretty-printed string representation:
        - "-" for unspecified narratives
        - Descriptive names for known types (e.g., "Yield", "Dividend")
        - Empty string for unknown values
    """
    if narrative == IncomeNarrative.INCOME_NARRATIVE_UNSPECIFIED:
        return "-"
    if narrative == IncomeNarrative.INCOME_NARRATIVE_YIELD:
        return "Yield"
    if narrative == IncomeNarrative.INCOME_NARRATIVE_DIVIDEND:
        return "Dividend"
    if narrative == IncomeNarrative.INCOME_NARRATIVE_INTEREST:
        return "Interest"
    if narrative == IncomeNarrative.INCOME_NARRATIVE_PRINCIPAL:
        return "Principal"
    if narrative == IncomeNarrative.INCOME_NARRATIVE_DISTRIBUTION:
        return "Distribution"
    if narrative == IncomeNarrative.INCOME_NARRATIVE_PROFIT_DISTRIBUTION:
        return "Profit Distribution"
    return ""



import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from meshtrade.type.v1 import decimal_pb2 as _decimal_pb2
from meshtrade.type.v1 import token_pb2 as _token_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Price(_message.Message):
    __slots__ = ("base_token", "quote_token", "mid_price", "time")
    BASE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    QUOTE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    MID_PRICE_FIELD_NUMBER: _ClassVar[int]
    TIME_FIELD_NUMBER: _ClassVar[int]
    base_token: _token_pb2.Token
    quote_token: _token_pb2.Token
    mid_price: _decimal_pb2.Decimal
    time: _timestamp_pb2.Timestamp
    def __init__(self, base_token: _Optional[_Union[_token_pb2.Token, _Mapping]] = ..., quote_token: _Optional[_Union[_token_pb2.Token, _Mapping]] = ..., mid_price: _Optional[_Union[_decimal_pb2.Decimal, _Mapping]] = ..., time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



from buf.validate import validate_pb2 as _validate_pb2
from meshtrade.ledger.transaction.v1 import transaction_state_pb2 as _transaction_state_pb2
from meshtrade.option.method_options.v1 import method_options_pb2 as _method_options_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetTransactionStateRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class GetTransactionStateResponse(_message.Message):
    __slots__ = ("state",)
    STATE_FIELD_NUMBER: _ClassVar[int]
    state: _transaction_state_pb2.TransactionState
    def __init__(self, state: _Optional[_Union[_transaction_state_pb2.TransactionState, str]] = ...) -> None: ...

class MonitorTransactionStateRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class MonitorTransactionStateResponse(_message.Message):
    __slots__ = ("state",)
    STATE_FIELD_NUMBER: _ClassVar[int]
    state: _transaction_state_pb2.TransactionState
    def __init__(self, state: _Optional[_Union[_transaction_state_pb2.TransactionState, str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/compliance/client/v1/natural_person.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/compliance/client/v1/natural_person.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from meshtrade.compliance.client.v1 import identification_document_type_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_identification__document__type__pb2
from meshtrade.compliance.client.v1 import pep_status_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_pep__status__pb2
from meshtrade.compliance.client.v1 import source_of_income_and_wealth_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_source__of__income__and__wealth__pb2
from meshtrade.compliance.client.v1 import tax_residency_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_tax__residency__pb2
from meshtrade.type.v1 import address_pb2 as meshtrade_dot_type_dot_v1_dot_address__pb2
from meshtrade.type.v1 import contact_details_pb2 as meshtrade_dot_type_dot_v1_dot_contact__details__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3meshtrade/compliance/client/v1/natural_person.proto\x12\x1emeshtrade.compliance.client.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x16google/type/date.proto\x1a\x41meshtrade/compliance/client/v1/identification_document_type.proto\x1a/meshtrade/compliance/client/v1/pep_status.proto\x1a@meshtrade/compliance/client/v1/source_of_income_and_wealth.proto\x1a\x32meshtrade/compliance/client/v1/tax_residency.proto\x1a\x1fmeshtrade/type/v1/address.proto\x1a\'meshtrade/type/v1/contact_details.proto\"\xdf\t\n\rNaturalPerson\x12%\n\tfull_name\x18\x01 \x01(\tB\x08\xbaH\x05r\x03\x18\xff\x01R\x08\x66ullName\x12\x35\n\rdate_of_birth\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\x0b\x64\x61teOfBirth\x12\xdd\x01\n\x16\x63ountry_of_citizenship\x18\x03 \x01(\tB\xa6\x01\xbaH\xa2\x01\xba\x01\x9e\x01\n\x1c\x63ountry_code.format.optional\x12Ocountry_of_citizenship must be empty or a valid ISO 3166-1 alpha-2 country code\x1a-size(this) == 0 || this.matches(\'^[A-Z]{2}$\')R\x14\x63ountryOfCitizenship\x12<\n\x15identification_number\x18\x04 \x01(\tB\x07\xbaH\x04r\x02\x18\x64R\x14identificationNumber\x12\x86\x01\n\x1cidentification_document_type\x18\x05 \x01(\x0e\x32:.meshtrade.compliance.client.v1.IdentificationDocumentTypeB\x08\xbaH\x05\x82\x01\x02\x10\x01R\x1aidentificationDocumentType\x12`\n#identification_document_expiry_date\x18\x06 \x01(\x0b\x32\x11.google.type.DateR identificationDocumentExpiryDate\x12\x45\n\x10physical_address\x18\x07 \x01(\x0b\x32\x1a.meshtrade.type.v1.AddressR\x0fphysicalAddress\x12\x41\n\x0epostal_address\x18\x08 \x01(\x0b\x32\x1a.meshtrade.type.v1.AddressR\rpostalAddress\x12R\n\npep_status\x18\t \x01(\x0e\x32).meshtrade.compliance.client.v1.PepStatusB\x08\xbaH\x05\x82\x01\x02\x10\x01R\tpepStatus\x12J\n\x0f\x63ontact_details\x18\n \x01(\x0b\x32!.meshtrade.type.v1.ContactDetailsR\x0e\x63ontactDetails\x12r\n\x11sources_of_income\x18\x0b \x03(\x0e\x32\x37.meshtrade.compliance.client.v1.SourceOfIncomeAndWealthB\r\xbaH\n\x92\x01\x07\"\x05\x82\x01\x02\x10\x01R\x0fsourcesOfIncome\x12r\n\x11sources_of_wealth\x18\x0c \x03(\x0e\x32\x37.meshtrade.compliance.client.v1.SourceOfIncomeAndWealthB\r\xbaH\n\x92\x01\x07\"\x05\x82\x01\x02\x10\x01R\x0fsourcesOfWealth\x12U\n\x0ftax_residencies\x18\r \x03(\x0b\x32,.meshtrade.compliance.client.v1.TaxResidencyR\x0etaxResidenciesBc\n%co.meshtrade.api.compliance.client.v1Z:github.com/meshtrade/api/go/compliance/client/v1;client_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.compliance.client.v1.natural_person_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%co.meshtrade.api.compliance.client.v1Z:github.com/meshtrade/api/go/compliance/client/v1;client_v1'
  _globals['_NATURALPERSON'].fields_by_name['full_name']._loaded_options = None
  _globals['_NATURALPERSON'].fields_by_name['full_name']._serialized_options = b'\272H\005r\003\030\377\001'
  _globals['_NATURALPERSON'].fields_by_name['country_of_citizenship']._loaded_options = None
  _globals['_NATURALPERSON'].fields_by_name['country_of_citizenship']._serialized_options = b'\272H\242\001\272\001\236\001\n\034country_code.format.optional\022Ocountry_of_citizenship must be empty or a valid ISO 3166-1 alpha-2 country code\032-size(this) == 0 || this.matches(\'^[A-Z]{2}$\')'
  _globals['_NATURALPERSON'].fields_by_name['identification_number']._loaded_options = None
  _globals['_NATURALPERSON'].fields_by_name['identification_number']._serialized_options = b'\272H\004r\002\030d'
  _globals['_NATURALPERSON'].fields_by_name['identification_document_type']._loaded_options = None
  _globals['_NATURALPERSON'].fields_by_name['identification_document_type']._serialized_options = b'\272H\005\202\001\002\020\001'
  _globals['_NATURALPERSON'].fields_by_name['pep_status']._loaded_options = None
  _globals['_NATURALPERSON'].fields_by_name['pep_status']._serialized_options = b'\272H\005\202\001\002\020\001'
  _globals['_NATURALPERSON'].fields_by_name['sources_of_income']._loaded_options = None
  _globals['_NATURALPERSON'].fields_by_name['sources_of_income']._serialized_options = b'\272H\n\222\001\007\"\005\202\001\002\020\001'
  _globals['_NATURALPERSON'].fields_by_name['sources_of_wealth']._loaded_options = None
  _globals['_NATURALPERSON'].fields_by_name['sources_of_wealth']._serialized_options = b'\272H\n\222\001\007\"\005\202\001\002\020\001'
  _globals['_NATURALPERSON']._serialized_start=449
  _globals['_NATURALPERSON']._serialized_end=1696
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from meshtrade.reporting.account_report.v1 import account_report_pb2 as meshtrade_dot_reporting_dot_account__report_dot_v1_dot_account__report__pb2
from meshtrade.reporting.account_report.v1 import service_pb2 as meshtrade_dot_reporting_dot_account__report_dot_v1_dot_service__pb2


class AccountReportServiceStub(object):
    """
    The AccountReportService provides endpoints for generating and exporting
    comprehensive account activity reports.

    Clients can use this service to retrieve structured reports containing income,
    fees, and trading statements for a specified account and time period. All
    financial values within the reports are denominated in a user-specified
    reporting currency.

    Access to all service methods requires appropriate Reporting domain permissions.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetAccountReport = channel.unary_unary(
                '/meshtrade.reporting.account_report.v1.AccountReportService/GetAccountReport',
                request_serializer=meshtrade_dot_reporting_dot_account__report_dot_v1_dot_service__pb2.GetAccountReportRequest.SerializeToString,
                response_deserializer=meshtrade_dot_reporting_dot_account__report_dot_v1_dot_account__report__pb2.AccountReport.FromString,
                _registered_method=True)
        self.GetExcelAccountReport = channel.unary_unary(
                '/meshtrade.reporting.account_report.v1.AccountReportService/GetExcelAccountReport',
                request_serializer=meshtrade_dot_reporting_dot_account__report_dot_v1_dot_service__pb2.GetExcelAccountReportRequest.SerializeToString,
                response_deserializer=meshtrade_dot_reporting_dot_account__report_dot_v1_dot_service__pb2.GetExcelAccountReportResponse.FromString,
                _registered_method=True)


class AccountReportServiceServicer(object):
    """
    The AccountReportService provides endpoints for generating and exporting
    comprehensive account activity reports.

    Clients can use this service to retrieve structured reports containing income,
    fees, and trading statements for a specified account and time period. All
    financial values within the reports are denominated in a user-specified
    reporting currency.

    Access to all service methods requires appropriate Reporting domain permissions.
    """

    def GetAccountReport(self, request, context):
        """
        Retrieves a structured account report.

        Generates a detailed report for the given account and time range, with all
        values denominated in the specified reporting asset token.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExcelAccountReport(self, request, context):
        """
        Exports an account report as a downloadable Excel file.

        Generates the same report as GetAccountReport but returns it as a
        base64-encoded string representing an Excel (.xlsx) file.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AccountReportServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetAccountReport': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccountReport,
                    request_deserializer=meshtrade_dot_reporting_dot_account__report_dot_v1_dot_service__pb2.GetAccountReportRequest.FromString,
                    response_serializer=meshtrade_dot_reporting_dot_account__report_dot_v1_dot_account__report__pb2.AccountReport.SerializeToString,
            ),
            'GetExcelAccountReport': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExcelAccountReport,
                    request_deserializer=meshtrade_dot_reporting_dot_account__report_dot_v1_dot_service__pb2.GetExcelAccountReportRequest.FromString,
                    response_serializer=meshtrade_dot_reporting_dot_account__report_dot_v1_dot_service__pb2.GetExcelAccountReportResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'meshtrade.reporting.account_report.v1.AccountReportService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('meshtrade.reporting.account_report.v1.AccountReportService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class AccountReportService(object):
    """
    The AccountReportService provides endpoints for generating and exporting
    comprehensive account activity reports.

    Clients can use this service to retrieve structured reports containing income,
    fees, and trading statements for a specified account and time period. All
    financial values within the reports are denominated in a user-specified
    reporting currency.

    Access to all service methods requires appropriate Reporting domain permissions.
    """

    @staticmethod
    def GetAccountReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.reporting.account_report.v1.AccountReportService/GetAccountReport',
            meshtrade_dot_reporting_dot_account__report_dot_v1_dot_service__pb2.GetAccountReportRequest.SerializeToString,
            meshtrade_dot_reporting_dot_account__report_dot_v1_dot_account__report__pb2.AccountReport.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetExcelAccountReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.reporting.account_report.v1.AccountReportService/GetExcelAccountReport',
            meshtrade_dot_reporting_dot_account__report_dot_v1_dot_service__pb2.GetExcelAccountReportRequest.SerializeToString,
            meshtrade_dot_reporting_dot_account__report_dot_v1_dot_service__pb2.GetExcelAccountReportResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



"""
Shared configuration options for all gRPC services.

This module provides a clean, extensible way to configure services with optional
parameters while maintaining backward compatibility and readability.
"""

from datetime import timedelta


class ServiceOptions:
    """Configuration options for gRPC services.

    This class provides a clean, extensible way to configure services with optional
    parameters while maintaining backward compatibility and readability.
    """

    def __init__(
        self,
        tls: bool = True,
        url: str | None = None,
        port: int | None = None,
        api_key: str | None = None,
        group: str | None = None,
        timeout: timedelta = timedelta(seconds=30),
    ):
        """Initialize service options.

        Args:
            tls: Whether to use TLS encryption for the gRPC connection.
            url: The server hostname or IP address.
            port: The server port number.
            api_key: The API key for authentication.
            group: The group resource name in format groups/{group_id}.
            timeout: The default timeout for all gRPC method calls.
        """
        self.tls = tls
        self.url = url
        self.port = port
        self.api_key = api_key
        self.group = group
        self.timeout = timeout


# Create alias to match expected exports
ClientOptions = ServiceOptions



"""Type v1 package."""

# ===================================================================
# AUTO-GENERATED SECTION - ONLY EDIT BELOW THE CLOSING COMMENT BLOCK
# ===================================================================
# This section is automatically managed by protoc-gen-meshpy.
#
# DO NOT EDIT ANYTHING IN THIS SECTION MANUALLY!
# Your changes will be overwritten during code generation.
#
# To add custom imports and exports, scroll down to the
# "MANUAL SECTION" indicated below.
# ===================================================================

# Generated protobuf imports
from .address_pb2 import Address
from .contact_details_pb2 import ContactDetails
from .decimal_pb2 import Decimal
from .sorting_pb2 import SortingOrder
from .ledger_pb2 import Ledger
from .token_pb2 import Token
from .amount_pb2 import Amount
from .date_pb2 import Date
from .time_of_day_pb2 import TimeOfDay

# ===================================================================
# END OF AUTO-GENERATED SECTION
# ===================================================================
#
# MANUAL SECTION - ADD YOUR CUSTOM IMPORTS AND EXPORTS BELOW
#
# You can safely add your own imports, functions, classes, and exports
# in this section. They will be preserved across code generation.
#
# Example:
#   from my_custom_module import my_function
#
# ===================================================================

from .amount import (
    amount_add,
    amount_contains_fractions,
    amount_decimal_div,
    amount_decimal_mul,
    amount_is_equal_to,
    amount_is_negative,
    amount_is_same_type_as,
    amount_is_undefined,
    amount_is_zero,
    amount_set_value,
    amount_sub,
    new_amount,
    new_undefined_amount,
)
from .date import (
    date_add_days,
    date_add_months,
    date_add_years,
    date_is_after,
    date_is_after_or_equal,
    date_is_before,
    date_is_before_or_equal,
    date_is_complete,
    date_is_equal,
    date_is_valid,
    date_to_python_date,
    date_to_string,
    new_date,
    new_date_from_python_date,
)
from .decimal_built_in_conversions import (
    built_in_to_decimal,
    decimal_to_built_in,
)
from .decimal_operations import (
    decimal_add,
    decimal_div,
    decimal_equal,
    decimal_greater_than,
    decimal_greater_than_or_equal,
    decimal_is_negative,
    decimal_is_positive,
    decimal_is_zero,
    decimal_less_than,
    decimal_less_than_or_equal,
    decimal_mul,
    decimal_round,
    decimal_sub,
)
from .ledger import (
    UnsupportedLedgerError,
    get_ledger_no_decimal_places,
    ledger_is_valid,
    ledger_is_valid_and_defined,
    ledger_to_pretty_string,
)
from .time_of_day import (
    new_time_of_day,
    new_time_of_day_from_datetime,
    new_time_of_day_from_python_time,
    new_time_of_day_from_timedelta,
    time_of_day_is_midnight,
    time_of_day_is_valid,
    time_of_day_to_datetime_with_date,
    time_of_day_to_python_time,
    time_of_day_to_string,
    time_of_day_to_timedelta,
    time_of_day_total_seconds,
)
from .token import (
    new_undefined_token,
    token_is_equal_to,
    token_is_undefined,
    token_pretty_string,
)

# ===================================================================
# MODULE EXPORTS
# ===================================================================
# Combined auto-generated and manual exports
__all__ = [
    # Generated exports
    "Address",
    "Amount",
    "ContactDetails",
    "Date",
    "Decimal",
    "Ledger",
    "SortingOrder",
    "TimeOfDay",
    "Token",
    # Manual exports
    "UnsupportedLedgerError",
    "amount_add",
    "amount_contains_fractions",
    "amount_decimal_div",
    "amount_decimal_mul",
    "amount_is_equal_to",
    "amount_is_negative",
    "amount_is_same_type_as",
    "amount_is_undefined",
    "amount_is_zero",
    "amount_set_value",
    "amount_sub",
    "built_in_to_decimal",
    "date_add_days",
    "date_add_months",
    "date_add_years",
    "date_is_after",
    "date_is_after_or_equal",
    "date_is_before",
    "date_is_before_or_equal",
    "date_is_complete",
    "date_is_equal",
    "date_is_valid",
    "date_to_python_date",
    "date_to_string",
    "decimal_add",
    "decimal_div",
    "decimal_equal",
    "decimal_greater_than",
    "decimal_greater_than_or_equal",
    "decimal_is_negative",
    "decimal_is_positive",
    "decimal_is_zero",
    "decimal_less_than",
    "decimal_less_than_or_equal",
    "decimal_mul",
    "decimal_round",
    "decimal_sub",
    "decimal_to_built_in",
    "get_ledger_no_decimal_places",
    "ledger_is_valid",
    "ledger_is_valid_and_defined",
    "ledger_to_pretty_string",
    "new_amount",
    "new_date",
    "new_date_from_python_date",
    "new_time_of_day",
    "new_time_of_day_from_datetime",
    "new_time_of_day_from_python_time",
    "new_time_of_day_from_timedelta",
    "new_undefined_amount",
    "new_undefined_token",
    "time_of_day_is_midnight",
    "time_of_day_is_valid",
    "time_of_day_to_datetime_with_date",
    "time_of_day_to_python_time",
    "time_of_day_to_string",
    "time_of_day_to_timedelta",
    "time_of_day_total_seconds",
    "token_is_equal_to",
    "token_is_undefined",
    "token_pretty_string",
]



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class Role(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    ROLE_UNSPECIFIED: _ClassVar[Role]
    ROLE_WALLET_ADMIN: _ClassVar[Role]
    ROLE_WALLET_VIEWER: _ClassVar[Role]
    ROLE_WALLET_ACCOUNT_ADMIN: _ClassVar[Role]
    ROLE_WALLET_ACCOUNT_VIEWER: _ClassVar[Role]
    ROLE_COMPLIANCE_ADMIN: _ClassVar[Role]
    ROLE_COMPLIANCE_VIEWER: _ClassVar[Role]
    ROLE_COMPLIANCE_CLIENT_ADMIN: _ClassVar[Role]
    ROLE_COMPLIANCE_CLIENT_VIEWER: _ClassVar[Role]
    ROLE_IAM_ADMIN: _ClassVar[Role]
    ROLE_IAM_VIEWER: _ClassVar[Role]
    ROLE_IAM_API_USER_ADMIN: _ClassVar[Role]
    ROLE_IAM_API_USER_VIEWER: _ClassVar[Role]
    ROLE_IAM_GROUP_ADMIN: _ClassVar[Role]
    ROLE_IAM_GROUP_VIEWER: _ClassVar[Role]
    ROLE_IAM_USER_ADMIN: _ClassVar[Role]
    ROLE_IAM_USER_VIEWER: _ClassVar[Role]
    ROLE_IAM_USER_PROFILE_ADMIN: _ClassVar[Role]
    ROLE_IAM_USER_PROFILE_VIEWER: _ClassVar[Role]
    ROLE_STUDIO_ADMIN: _ClassVar[Role]
    ROLE_STUDIO_VIEWER: _ClassVar[Role]
    ROLE_STUDIO_INSTRUMENT_ADMIN: _ClassVar[Role]
    ROLE_STUDIO_INSTRUMENT_VIEWER: _ClassVar[Role]
    ROLE_TRADING_ADMIN: _ClassVar[Role]
    ROLE_TRADING_VIEWER: _ClassVar[Role]
    ROLE_TRADING_LIMIT_ORDER_ADMIN: _ClassVar[Role]
    ROLE_TRADING_LIMIT_ORDER_VIEWER: _ClassVar[Role]
    ROLE_REPORTING_ADMIN: _ClassVar[Role]
    ROLE_REPORTING_VIEWER: _ClassVar[Role]
    ROLE_LEDGER_ADMIN: _ClassVar[Role]
    ROLE_LEDGER_VIEWER: _ClassVar[Role]
    ROLE_LEDGER_TRANSACTION_ADMIN: _ClassVar[Role]
    ROLE_LEDGER_TRANSACTION_VIEWER: _ClassVar[Role]
    ROLE_MARKET_DATA_ADMIN: _ClassVar[Role]
    ROLE_MARKET_DATA_VIEWER: _ClassVar[Role]
    ROLE_MARKET_DATA_PRICE_ADMIN: _ClassVar[Role]
    ROLE_MARKET_DATA_PRICE_VIEWER: _ClassVar[Role]
    ROLE_TESTING_LEDGER_TOKEN_TAP_ADMIN: _ClassVar[Role]
    ROLE_TESTING_LEDGER_TOKEN_TAP_VIEWER: _ClassVar[Role]
ROLE_UNSPECIFIED: Role
ROLE_WALLET_ADMIN: Role
ROLE_WALLET_VIEWER: Role
ROLE_WALLET_ACCOUNT_ADMIN: Role
ROLE_WALLET_ACCOUNT_VIEWER: Role
ROLE_COMPLIANCE_ADMIN: Role
ROLE_COMPLIANCE_VIEWER: Role
ROLE_COMPLIANCE_CLIENT_ADMIN: Role
ROLE_COMPLIANCE_CLIENT_VIEWER: Role
ROLE_IAM_ADMIN: Role
ROLE_IAM_VIEWER: Role
ROLE_IAM_API_USER_ADMIN: Role
ROLE_IAM_API_USER_VIEWER: Role
ROLE_IAM_GROUP_ADMIN: Role
ROLE_IAM_GROUP_VIEWER: Role
ROLE_IAM_USER_ADMIN: Role
ROLE_IAM_USER_VIEWER: Role
ROLE_IAM_USER_PROFILE_ADMIN: Role
ROLE_IAM_USER_PROFILE_VIEWER: Role
ROLE_STUDIO_ADMIN: Role
ROLE_STUDIO_VIEWER: Role
ROLE_STUDIO_INSTRUMENT_ADMIN: Role
ROLE_STUDIO_INSTRUMENT_VIEWER: Role
ROLE_TRADING_ADMIN: Role
ROLE_TRADING_VIEWER: Role
ROLE_TRADING_LIMIT_ORDER_ADMIN: Role
ROLE_TRADING_LIMIT_ORDER_VIEWER: Role
ROLE_REPORTING_ADMIN: Role
ROLE_REPORTING_VIEWER: Role
ROLE_LEDGER_ADMIN: Role
ROLE_LEDGER_VIEWER: Role
ROLE_LEDGER_TRANSACTION_ADMIN: Role
ROLE_LEDGER_TRANSACTION_VIEWER: Role
ROLE_MARKET_DATA_ADMIN: Role
ROLE_MARKET_DATA_VIEWER: Role
ROLE_MARKET_DATA_PRICE_ADMIN: Role
ROLE_MARKET_DATA_PRICE_VIEWER: Role
ROLE_TESTING_LEDGER_TOKEN_TAP_ADMIN: Role
ROLE_TESTING_LEDGER_TOKEN_TAP_VIEWER: Role
